Copyright (c) 2017 Intel Corporation. All rights reserved.
Use of this source code is governed by a MIT-style
license that can be found in the LICENSE file.

iml-common is a python library package required by multiple IML components.

[![Build Status](https://travis-ci.org/intel-hpdd/iml-common.svg?branch=master)](https://travis-ci.org/intel-hpdd/iml-common)
